# Griseo

Chat with OpenAI in the Hacker way.

## Installation

```shell
pip install griseo
```

## Usage

```shell
export OPENAI_API_KEY=<API_TOKEN> # or echo OPENAI_API_KEY=<API_TOKEN> >> .env
griseo ... # one-shot chat completion
griseo     # open an interactive session  
```
